handle_file_list

Function handle_file_list 

pub async fn handle_file_list(
    server: &ProtocolServer,
    req: FileListRequest,
) -> Result<Response<FileListResponse>, Status>
Handle a FileList RPC.

Lists files visible in the session workspace, optionally filtered to only modified files or by a path prefix.