handle_file_write

Function handle_file_write 

pub async fn handle_file_write(
    server: &ProtocolServer,
    req: FileWriteRequest,
) -> Result<Response<FileWriteResponse>, Status>
Handle a FileWrite RPC.

Writes a file through the session workspace overlay and optionally detects symbol changes by parsing the new content.