pub struct Change {
pub type: i32,
pub symbol_name: String,
pub file_path: String,
pub old_symbol_id: Option<String>,
pub new_source: String,
pub rationale: String,
}Fields
type: i32symbol_name: Stringfile_path: Stringold_symbol_id: Option<String>new_source: Stringrationale: StringImplementations
Sourceimpl Change
impl Change
Sourcepub fn type(&self) -> ChangeType
pub fn type(&self) -> ChangeType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ChangeType)
pub fn set_type(&mut self, value: ChangeType)
Sets type to the provided enum value.
Sourcepub fn old_symbol_id(&self) -> &str
pub fn old_symbol_id(&self) -> &str
Returns the value of old_symbol_id, or the default value if old_symbol_id is unset.