pub struct ResolveRequest {
pub session_id: String,
pub resolution: i32,
pub conflict_id: Option<String>,
pub manual_content: Option<String>,
}Fields
session_id: Stringresolution: i32conflict_id: Option<String>manual_content: Option<String>Implementations
Sourceimpl ResolveRequest
impl ResolveRequest
Sourcepub fn resolution(&self) -> ResolutionMode
pub fn resolution(&self) -> ResolutionMode
Returns the enum value of resolution, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: ResolutionMode)
pub fn set_resolution(&mut self, value: ResolutionMode)
Sets resolution to the provided enum value.
Sourcepub fn conflict_id(&self) -> &str
pub fn conflict_id(&self) -> &str
Returns the value of conflict_id, or the default value if conflict_id is unset.
Sourcepub fn manual_content(&self) -> &str
pub fn manual_content(&self) -> &str
Returns the value of manual_content, or the default value if manual_content is unset.