pub struct WorkspaceConfig {
pub mode: i32,
pub base_commit: Option<String>,
pub resume_session_id: Option<String>,
pub watch_other_sessions: bool,
}Fields
mode: i32base_commit: Option<String>resume_session_id: Option<String>watch_other_sessions: boolImplementations
Sourceimpl WorkspaceConfig
impl WorkspaceConfig
Sourcepub fn mode(&self) -> WorkspaceMode
pub fn mode(&self) -> WorkspaceMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: WorkspaceMode)
pub fn set_mode(&mut self, value: WorkspaceMode)
Sets mode to the provided enum value.
Sourcepub fn base_commit(&self) -> &str
pub fn base_commit(&self) -> &str
Returns the value of base_commit, or the default value if base_commit is unset.
Sourcepub fn resume_session_id(&self) -> &str
pub fn resume_session_id(&self) -> &str
Returns the value of resume_session_id, or the default value if resume_session_id is unset.