pub struct CompetingChangeset {
pub changeset_id: Uuid,
pub session_id: Option<Uuid>,
pub state: String,
pub updated_at: DateTime<Utc>,
}Expand description
Minimal view of a submitted-but-not-merged changeset that touched the same file path as the write we’re about to perform.
Fields
changeset_id: Uuidsession_id: Option<Uuid>state: Stringupdated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for CompetingChangeset
impl Clone for CompetingChangeset
Sourcefn clone(&self) -> CompetingChangeset
fn clone(&self) -> CompetingChangeset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompetingChangeset
impl Debug for CompetingChangeset
impl Eq for CompetingChangeset
Sourceimpl PartialEq for CompetingChangeset
impl PartialEq for CompetingChangeset
Sourcefn eq(&self, other: &CompetingChangeset) -> bool
fn eq(&self, other: &CompetingChangeset) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompetingChangeset