pub async fn handle_file_list(
server: &ProtocolServer,
req: FileListRequest,
) -> Result<Response<FileListResponse>, Status>Expand description
Handle a FileList RPC.
Lists files visible in the session workspace, optionally filtered to only modified files or by a path prefix.